@@ -111,9 +111,9 @@ test_that(
 # Functional Requirement 3 ------------------------------------------
 
 test_that(
-  "Casts an error if bg is not a character(1)",
+  "Casts an error if halign is not a character",
   {
-    expect_error(sprinkle_align(x, halign = c("left", "center")))
+    expect_error(sprinkle_align(x, halign = c(1:2)))
   }
 )
 
@@ -142,9 +142,84 @@ test_that(
   }
 )
 
+# Functional Requirement 6 ------------------------------------------
+
 test_that(
   "Casts an error if recycle is not one of none, rows, or cols",
   {
     expect_error(sprinkle_align(x, halign = "right", recycle = "not_an_option"))
   }
-)
\ No newline at end of file
+)
+
+# Functional Requirement 7 ------------------------------------------
+
+test_that(
+  "Casts an error if valign is not a character",
+  {
+    expect_error(sprinkle_align(x, valign = c(1:2)))
+  }
+)
+
+# Functional Requirement 8 ------------------------------------------
+
+test_that(
+  "Cast an error if recycle = 'none' and halign does not have length 1.",
+  {
+    expect_error(
+      sprinkle(sprinkle_align(x, halign = c("left", "right")))
+    )
+  }
+)
+
+test_that(
+  "Passes if recycle != 'none' and halign does not have length 1.",
+  {
+    expect_silent(
+      sprinkle_align(x, halign = c("left", "right"),
+                              recycle = "rows")
+    )
+  }
+)
+
+# Functional Requirement 9 ------------------------------------------
+
+test_that(
+  "Cast an error if recycle = 'none' and halign does not have length 1.",
+  {
+    expect_error(
+      sprinkle(sprinkle_align(x, valign = c("bottom", "top")))
+    )
+  }
+)
+
+test_that(
+  "Passes if recycle != 'none' and halign does not have length 1.",
+  {
+    expect_silent(
+      sprinkle_align(x, valign = c("bottom", "top"),
+                     recycle = "rows")
+    )
+  }
+)
+
+# Functional Requirement 10 -----------------------------------------
+
+test_that(
+  "Cast an error if halign is not one of c('left', 'center', 'right')",
+  {
+    expect_error(
+      sprinkle_align(x, halign = "something")
+    )
+  }
+)
+
+# Functional Requirement 11 -----------------------------------------
+
+test_that(
+  "Cast an error if valign is not one of c('bottom', 'middle', 'top')",
+  {
+    expect_error(
+      sprinkle_align(x, valign = "something")
+    )
+  }
+)
